==> wireshark_4.4.9.orig.tar.bz2: wireshark-v4.4.9/cmake/modules/UseLemon.cmake <==
#

find_program(LEMON_EXECUTABLE lemon)

if(LEMON_EXECUTABLE)
	# Use system lemon
	macro(generate_lemon_file _out _in)
		add_custom_command(
			OUTPUT
				${_out}.c
				# These files are generated as side-effect
				${_out}.h
				${_out}.out
			COMMAND ${LEMON_EXECUTABLE}
				-T/usr/share/lemon/lempar.c
				-d.
				${_in}
			DEPENDS
				${_in}
		)
	endmacro()
	add_custom_target(lemon)
else()
	# Compile bundled lemon with support for -- to end options
	macro(generate_lemon_file _out _in)
		add_custom_command(
			OUTPUT
				${_out}.c
				# These files are generated as side-effect
				${_out}.h
				${_out}.out
			COMMAND $<TARGET_FILE:lemon>
				-T${CMAKE_SOURCE_DIR}/tools/lemon/lempar.c
				-d.
				--
				${_in}
			DEPENDS
				${_in}
				lemon
				${CMAKE_SOURCE_DIR}/tools/lemon/lempar.c
		)
	endmacro()
endif()

macro(ADD_LEMON_FILES _source _generated)

	foreach (_current_FILE ${ARGN})
		get_filename_component(_in ${_current_FILE} ABSOLUTE)
		get_filename_component(_basename ${_current_FILE} NAME_WE)

		set(_out ${CMAKE_CURRENT_BINARY_DIR}/${_basename})

		generate_lemon_file(${_out} ${_in})

		list(APPEND ${_source} ${_in})
		list(APPEND ${_generated} ${_out}.c)

		# Our Lemon generated code has unused parameters. Turn that warning off.
		if(CMAKE_C_COMPILER_ID MATCHES "MSVC")
			set_source_files_properties(${_out}.c PROPERTIES COMPILE_OPTIONS "/wd4100")
		elseif(CMAKE_C_COMPILER_ID MATCHES "GNU|Clang")
			set_source_files_properties(${_out}.c PROPERTIES COMPILE_OPTIONS "-Wno-unused-parameter")
		else()
			# Build with some warnings for lemon generated code
		endif()
	endforeach(_current_FILE)
endmacro(ADD_LEMON_FILES)

==> wireshark_4.6.2.orig.tar.bz2: wireshark-v4.6.2/cmake/modules/UseLemon.cmake <==
# Create macros for using the lemon parser generator.

# If we're cross-compiling and /usr/share/lemon/lempar.c exists, try to
# find the system lemon and use it. We need to build our own lemon
# otherwise.
if (CMAKE_CROSSCOMPILING AND EXISTS /usr/share/lemon/lempar.c)
	find_program(LEMON_EXECUTABLE lemon)
endif()

if(LEMON_EXECUTABLE)
	# Use system lemon
	macro(generate_lemon_file _out _in)
		add_custom_command(
			OUTPUT
				${_out}.c
				# These files are generated as side-effect
				${_out}.h
				${_out}.out
			COMMAND ${LEMON_EXECUTABLE}
				-T/usr/share/lemon/lempar.c
				-d.
				${_in}
			DEPENDS
				${_in}
		)
	endmacro()
	add_custom_target(lemon)
else()
	# Compile bundled lemon with support for -- to end options
	macro(generate_lemon_file _out _in)
		add_custom_command(
			OUTPUT
				${_out}.c
				# These files are generated as side-effect
				${_out}.h
				${_out}.out
			COMMAND $<TARGET_FILE:lemon>
				-T${CMAKE_SOURCE_DIR}/tools/lemon/lempar.c
				-d.
				--
				${_in}
			DEPENDS
				${_in}
				lemon
				${CMAKE_SOURCE_DIR}/tools/lemon/lempar.c
		)
	endmacro()
endif()

macro(ADD_LEMON_FILES _source _generated)

	foreach (_current_FILE ${ARGN})
		get_filename_component(_in ${_current_FILE} ABSOLUTE)
		get_filename_component(_basename ${_current_FILE} NAME_WE)

		set(_out ${CMAKE_CURRENT_BINARY_DIR}/${_basename})

		generate_lemon_file(${_out} ${_in})

		list(APPEND ${_source} ${_in})
		list(APPEND ${_generated} ${_out}.c)
	endforeach(_current_FILE)
endmacro(ADD_LEMON_FILES)
